package App::PerinciUtils;

our $DATE = '2015-07-30'; # DATE
our $VERSION = '0.05'; # VERSION

use 5.010001;

1;
# ABSTRACT: Some utilities related to Perinci

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PerinciUtils - Some utilities related to Perinci

=head1 VERSION

This document describes version 0.05 of App::PerinciUtils (from Perl distribution App-PerinciUtils), released on 2015-07-30.

=head1 DESCRIPTION

This distribution includes a few utility scripts related to Perinci::* modules
family.

=over

=item * L<peri-access>

=item * L<peri-htserve>

=item * L<peri-run>

=item * L<wrap-with-perinci-sub-wrapper>

=back

=head1 SEE ALSO

L<Perinci>

L<App::PericmdUtils> - utilities related to Perinci::CmdLine modules family.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PerinciUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-PerinciUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PerinciUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
